@@ -607,3 +607,22 @@ if(window && title)
 		}
 	}
 }
+
+
+char *realpath_2(const char *path, char *resolved_path)
+{
+#if defined __USE_BSD || defined __USE_XOPEN_EXTENDED || defined __CYGWIN__ || defined HAVE_REALPATH
+
+#if (defined(__MACH__) && defined(__APPLE__))
+if(!resolved_path)
+	{
+	resolved_path = malloc(PATH_MAX+1); /* fixes bug on Leopard when resolved_path == NULL */
+	}
+#endif
+
+return(realpath(path, resolved_path));
+
+#else
+return(NULL);
+#endif
+}
