@@ -1056,6 +1056,7 @@ NULL, /* vcd_jmp_buf */
 1, /* atomic_vectors 476 */
 0, /* make_vcd_save_file 477 */
 0, /* vcd_preserve_glitches 478 */
+0, /* vcd_preserve_glitches_real */
 NULL, /* vcd_save_handle 479 */
 NULL, /* vcd_handle_vcd_c_1 480 */
 0, /* vcd_is_compressed_vcd_c_1 481 */
@@ -1292,6 +1293,7 @@ WAVE_RAINBOW_INITIALIZER, /* gc_rainbow */
  */
 1, /* do_zoom_center 660 */
 0, /* do_initial_zoom_fit 661 */
+0, /* do_initial_zoom_fit_used */
 };
 
 
@@ -1777,6 +1779,7 @@ void reload_into_new_context_2(void)
  new_globals->disable_tooltips = GLOBALS->disable_tooltips;
  new_globals->do_hier_compress = GLOBALS->do_hier_compress;
  new_globals->do_initial_zoom_fit = GLOBALS->do_initial_zoom_fit;
+ new_globals->do_initial_zoom_fit_used = GLOBALS->do_initial_zoom_fit_used;
  new_globals->do_resize_signals = GLOBALS->do_resize_signals;
  new_globals->alt_wheel_mode = GLOBALS->alt_wheel_mode;
  new_globals->initial_signal_window_width = GLOBALS->initial_signal_window_width;
@@ -1806,6 +1809,7 @@ void reload_into_new_context_2(void)
  new_globals->use_scrollbar_only = GLOBALS->use_scrollbar_only;
  new_globals->vcd_explicit_zero_subscripts = GLOBALS->vcd_explicit_zero_subscripts;
  new_globals->vcd_preserve_glitches = GLOBALS->vcd_preserve_glitches;
+ new_globals->vcd_preserve_glitches_real = GLOBALS->vcd_preserve_glitches_real;
  new_globals->vcd_warning_filesize = GLOBALS->vcd_warning_filesize;
  new_globals->vector_padding = GLOBALS->vector_padding;
  new_globals->vlist_prepack = GLOBALS->vlist_prepack;
