@@ -30,6 +30,157 @@
 #include "../../contrib/rtlbrowse/jrb.h"
 #include "wave_locale.h"
 
+
+#ifdef EXTLOAD_SUFFIX
+#ifdef EXTCONV_PATH
+#define VCD2FST_EXTLOAD_CONV
+#endif
+#endif
+
+/*********************************************************/
+/*** vvv extload component type name determination vvv ***/
+/*********************************************************/
+
+#if defined(VCD2FST_EXTLOAD_CONV)
+
+#include <Judy.h>
+
+#ifdef _WAVE_HAVE_JUDY
+Pvoid_t  PJArray = NULL;
+#else
+JRB comp_name_jrb = NULL;
+#endif
+
+static const char *fst_scope_name = NULL;
+
+static char *get_scopename(void *xc, FILE *extload)
+{
+static char sbuff[65537];
+char * rc;
+int vt, vt_len;
+#ifdef _WAVE_HAVE_JUDY
+PPvoid_t PPValue;
+#else
+JRB str;
+Jval jv;
+#endif
+
+for(;;)
+        {
+        rc = fgets(sbuff, 65536, extload);
+        if(!rc)
+                {
+                return(NULL);
+                }
+
+        if(rc[0] == 'S')
+                {
+                if(!strncmp(rc, "Scope:", 6))
+                        {
+                        char vht[2048];
+                        char cname[2048];
+                        char ctype[2048];
+
+			cname[0] = ctype[0] = 0;
+
+                        sscanf(rc+6, "%s %s %s", vht, cname, ctype);
+                        fst_scope_name = fstReaderPushScope(xc, cname, NULL);
+
+			/* process fst_scope_name + cname vs ctype here */
+			if(strcmp(ctype, "NULL") && strcmp(cname, ctype))
+				{
+#ifdef _WAVE_HAVE_JUDY
+				PPValue = JudySLIns(&PJArray, (uint8_t *)fst_scope_name, PJE0);
+				if(!*((char **)PPValue))
+					{
+					*((char **)PPValue) = strdup(ctype);
+					}
+#else
+				char cstring[65537];
+				strcpy(cstring, fst_scope_name);
+				str = jrb_find_str(comp_name_jrb, cstring);
+				if(!str)
+					{
+					jv.s = strdup(ctype);
+					jrb_insert_str(comp_name_jrb, strdup(cstring), jv);
+					}
+#endif
+				}
+                        }
+                }
+        else
+        if(rc[0] == 'U')
+                {
+                fst_scope_name = fstReaderPopScope(xc);
+                }
+        }
+
+return(rc);
+}
+
+
+static void iter_scope(char *fname)
+{
+char sbuff[65537];
+FILE *extload;
+void *xc = fstReaderOpenForUtilitiesOnly();
+
+sprintf(sbuff, "%s -scope %s 2>&1", EXTLOAD_PATH, fname);
+extload = popen(sbuff, "r");
+
+while(get_scopename(xc, extload));
+
+pclose(extload);
+fstReaderClose(xc); /* corresponds to fstReaderOpenForUtilitiesOnly() */
+}
+
+
+static void dealloc_scope(void)
+{
+#ifdef _WAVE_HAVE_JUDY
+PPvoid_t PPValue;
+
+if(PJArray)
+        {
+        char Index[65537];
+	Index[0] = 0;
+
+        for (PPValue  = JudySLFirst (PJArray, (uint8_t *)Index, PJE0);
+                 PPValue != (PPvoid_t) NULL;
+                 PPValue  = JudySLNext  (PJArray, (uint8_t *)Index, PJE0))
+            {
+		free(*(char **)PPValue);
+            }
+
+        JudySLFreeArray(&PJArray, PJE0);
+        PJArray = NULL;
+        }
+#else
+if(comp_name_jrb)
+	{
+        JRB node;
+	char *Index;
+
+        jrb_traverse(node, comp_name_jrb)
+            {
+                Index = node->key.s;
+                free(Index);
+                Index = node->val.s;
+                free(Index);
+            }
+
+        jrb_free_tree(comp_name_jrb);
+        comp_name_jrb = NULL;
+	}
+#endif
+}
+
+#endif
+
+/*********************************************************/
+/*** ^^^ extload component type name determination ^^^ ***/
+/*********************************************************/
+
 size_t getline_replace(char **wbuf, char **buf, size_t *len, FILE *f)
 {
 char *fgets_rc;
@@ -77,12 +228,20 @@ int pack_type = 0;  /* set to 1 for fastlz */
 int repack_all = 0; /* 0 is normal, 1 does the repack (via fstapi) at end */
 int parallel_mode = 0; /* 0 is is single threaded, 1 is multi-threaded */
 
+
+static int suffix_check(const char *s, const char *sfx)
+{
+int sfxlen = strlen(sfx);
+return((strlen(s)>=sfxlen)&&(!strcasecmp(s+strlen(s)-sfxlen,sfx)));
+}
+
+
 int fst_main(char *vname, char *fstname)
 {
 FILE *f;
 char *buf = NULL, *wbuf = NULL;
 size_t glen;
-struct fstContext *ctx;
+void *ctx;
 int line = 0;
 size_t ss;
 fstHandle returnedhandle;
@@ -92,6 +251,10 @@ char bin_fixbuff[32769];
 int hash_kill = 0;
 unsigned int hash_max = 0;
 int *node_len_array = NULL;
+int is_popen = 0;
+#ifdef VCD2FST_EXTLOAD_CONV
+void *xc = NULL;
+#endif
 
 if(!strcmp("-", vname))
 	{
@@ -99,7 +262,22 @@ if(!strcmp("-", vname))
 	}
 	else
 	{
-	f = fopen(vname, "rb");
+#ifdef VCD2FST_EXTLOAD_CONV
+	if(suffix_check(vname, "."EXTLOAD_SUFFIX))
+		{
+		sprintf(bin_fixbuff, EXTCONV_PATH" %s", vname);
+		f = popen(bin_fixbuff, "r");
+		is_popen = 1;
+#ifndef _WAVE_HAVE_JUDY
+		comp_name_jrb = make_jrb();
+#endif
+		iter_scope(vname);
+		}
+		else
+#endif
+		{
+		f = fopen(vname, "rb");
+		}
 	}
 
 if(!f)
@@ -116,6 +294,13 @@ if(!ctx)
 	exit(255);
 	}
 
+#if defined(VCD2FST_EXTLOAD_CONV)
+if(is_popen)
+	{
+	xc = fstReaderOpenForUtilitiesOnly();
+	}
+#endif
+
 vcd_ids = make_jrb();
 fstWriterSetPackType(ctx, pack_type);
 fstWriterSetRepackOnClose(ctx, repack_all);
@@ -347,16 +532,58 @@ while(!feof(f))
 
 		st = strtok(NULL, " \t");
 
-		fstWriterSetScope(ctx, scopetype, st, NULL);
+#if defined(VCD2FST_EXTLOAD_CONV)
+#ifdef _WAVE_HAVE_JUDY
+		if(PJArray)
+			{
+			const char *fst_scope_name = fstReaderPushScope(xc, st, NULL);
+			PPvoid_t PPValue = JudySLGet(PJArray, (uint8_t *)fst_scope_name, PJE0);
+
+			fstWriterSetScope(ctx, scopetype, st, PPValue ? *PPValue : NULL);
+			}
+#else
+		if(comp_name_jrb)
+			{
+			const char *fst_scope_name = fstReaderPushScope(xc, st, NULL);
+			char cstring[65537];
+			JRB str;
+
+			strcpy(cstring, fst_scope_name);
+			str = jrb_find_str(comp_name_jrb, cstring);
+
+			fstWriterSetScope(ctx, scopetype, st, str ? str->val.s : NULL);
+			}
+#endif
+			else
+#endif
+			{
+			fstWriterSetScope(ctx, scopetype, st, NULL);
+			}
 		}
 	else
 	if(!strncmp(buf, "$upscope", 8))
 		{
 		fstWriterSetUpscope(ctx);
+#if defined(VCD2FST_EXTLOAD_CONV)
+		if(xc)
+			{
+			fstReaderPopScope(xc);
+			}
+#endif
 		}
 	else
 	if(!strncmp(buf, "$endd", 5))
 		{
+#if defined(VCD2FST_EXTLOAD_CONV)
+#ifdef _WAVE_HAVE_JUDY
+		if(PJArray)
+#else
+		if(comp_name_jrb)
+#endif
+			{
+			dealloc_scope();
+			}
+#endif
 		break;
 		}
 	else
@@ -813,6 +1040,14 @@ while(!feof(f))
 
 fstWriterClose(ctx);
 
+#if defined(VCD2FST_EXTLOAD_CONV)
+if(xc)
+	{
+	fstReaderClose(xc);
+	}
+#endif
+
+
 if(vcd_ids)
 	{
 	jrb_free_tree(vcd_ids);
@@ -822,7 +1057,17 @@ if(vcd_ids)
 free(wbuf); wbuf = NULL;
 free(node_len_array); node_len_array = NULL;
 
-if(f != stdin) fclose(f);
+if(f != stdin) 
+	{ 
+	if(is_popen)
+		{
+		pclose(f);
+		}
+		else
+		{
+		fclose(f);
+		}
+	}
 
 return(0);
 }
@@ -830,10 +1075,25 @@ return(0);
 
 void print_help(char *nam)
 {
+#ifdef VCD2FST_EXTLOAD_CONV
+int slen = strlen(EXTLOAD_SUFFIX);
+char *ucase_ext = calloc(1, slen+1);
+int i;
+
+for(i=0;i<slen;i++)
+	{
+	ucase_ext[i] = toupper(EXTLOAD_SUFFIX[i]);
+	}
+#endif
+
 #ifdef __linux__ 
 printf(
 "Usage: %s [OPTION]... [VCDFILE] [FSTFILE]\n\n"
+#ifdef VCD2FST_EXTLOAD_CONV
+"  -v, --vcdname=FILE         specify VCD/%s input filename\n"
+#else
 "  -v, --vcdname=FILE         specify VCD input filename\n"
+#endif
 "  -f, --fstname=FILE         specify FST output filename\n"
 "  -F, --fastpack             use fastlz algorithm for speed\n"
 "  -c, --compress             compress entire file on close\n"
@@ -842,11 +1102,19 @@ printf(
 
 "Note that VCDFILE and FSTFILE are optional provided the\n"
 "--vcdname and --fstname options are specified.\n\n"
-"Report bugs to <"PACKAGE_BUGREPORT">.\n",nam);
+"Report bugs to <"PACKAGE_BUGREPORT">.\n",nam
+#ifdef VCD2FST_EXTLOAD_CONV
+,ucase_ext
+#endif
+);
 #else
 printf(
 "Usage: %s [OPTION]... [VCDFILE] [FSTFILE]\n\n"
+#ifdef VCD2FST_EXTLOAD_CONV
+"  -v FILE                    specify VCD/%s input filename\n"
+#else
 "  -v FILE                    specify VCD input filename\n"
+#endif
 "  -f FILE                    specify FST output filename\n"
 "  -F                         use fastlz algorithm for speed\n"
 "  -c                         compress entire file on close\n"
@@ -855,7 +1123,15 @@ printf(
 
 "Note that VCDFILE and FSTFILE are optional provided the\n"
 "--vcdname and --fstname options are specified.\n\n"
-"Report bugs to <"PACKAGE_BUGREPORT">.\n",nam);
+"Report bugs to <"PACKAGE_BUGREPORT">.\n",nam
+#ifdef VCD2FST_EXTLOAD_CONV
+,ucase_ext
+#endif
+);
+#endif
+
+#ifdef VCD2FST_EXTLOAD_CONV
+free(ucase_ext);
 #endif
 
 exit(0);
