@@ -1319,6 +1319,9 @@ do_tooltips:
 
 	switch(GLOBALS->loaded_file_type)
 		{
+#ifdef EXTLOAD_SUFFIX
+		case EXTLOAD_FILE:
+#endif
 		case FST_FILE:
 		case AE2_FILE:
 		case VCD_FILE:
@@ -1581,6 +1584,9 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
 
 	switch(GLOBALS->loaded_file_type)
 		{
+#ifdef EXTLOAD_SUFFIX
+		case EXTLOAD_FILE:
+#endif
 		case FST_FILE:
 		case AE2_FILE:
 		case VCD_FILE:
